..
    This file is part of Invenio.
    Copyright (C) 2017-2018 CERN.

    Invenio is free software; you can redistribute it and/or modify it
    under the terms of the MIT License; see LICENSE file for more details.

.. _deployment-guide:

Deployment Guide
----------------
This part of the documentation will show you how to setup a production system
for running Invenio.

.. toctree::
    :maxdepth: 2

    overview
    services
    installation-detailed
    configuring
    daemons
    monitoring
    highavailability
    fabric
    docker
